import 'package:fis_measure/interfaces/process/workspace/application.dart';
import 'package:fis_ui/index.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';

class ButtonGroup extends StatefulWidget {
  final VoidCallback capturePng;
  const ButtonGroup({
    Key? key,
    required this.capturePng,
  }) : super(key: key);

  @override
  State<ButtonGroup> createState() => _ButtonGroupState();
}

class _ButtonGroupState extends State<ButtonGroup> {
  double _width = 0;
  bool _isExpanded = false;
  final _key = GlobalKey();
  final application = Get.find<IApplication>();

  Future<bool> _showList() async {
    await Future.delayed(const Duration(milliseconds: 300));
    return true;
  }

  /// TODO 翻译
  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.end,
      children: [
        AnimatedContainer(
          duration: const Duration(milliseconds: 300),
          padding: const EdgeInsets.only(
            top: 5,
            bottom: 5,
            left: 15,
          ),
          decoration: BoxDecoration(
            borderRadius: const BorderRadius.only(
              topLeft: Radius.circular(4),
              bottomLeft: Radius.circular(4),
            ),
            color: Colors.grey.withOpacity(0.6),
          ),
          width: _width,
          height: 60,
          child: _isExpanded
              ? FutureBuilder(
                  future: _showList(),
                  builder: (context, snapshot) {
                    if (!snapshot.hasData) {
                      return const SizedBox();
                    }
                    return Row(
                      children: [
                        _buildTitleButton(FIcons.fis_quash, '撤销',
                            () => application.undoRecord()),
                        _buildTitleButton(FIcons.fis_purge, '清除',
                            () => application.clearRecords()),
                        _buildTitleButton(FIcons.fis_full_screen, '全屏', () {
                          print('全屏');
                        }),
                        _buildTitleButton(
                            FIcons.fis_save, '保存', widget.capturePng),
                        _buildTitleButton(FIcons.fis_share, '分享', () {
                          print('分享');
                        }),
                      ],
                    );
                  })
              : const SizedBox(),
        ),
        InkWell(
          onTap: () {
            if (!_isExpanded) {
              setState(() {
                _width = 220;
                _isExpanded = true;
              });
            } else {
              setState(() {
                _width = 0;
                _isExpanded = false;
              });
            }
          },
          child: Container(
            height: 60,
            color: Colors.white,
            child: !_isExpanded
                ? const Icon(Icons.chevron_left_rounded)
                : const Icon(Icons.chevron_right_rounded),
          ),
        ),
      ],
      // ),
    );
  }

  Widget _buildTitleButton(IconData icon, String title, Function onClick) {
    return Container(
      margin: const EdgeInsets.only(
        right: 10,
      ),
      child: InkWell(
        onTap: () => onClick.call(),
        child: Column(
          children: [
            Icon(
              icon,
              color: Colors.white,
            ),
            Text(
              title,
              style: const TextStyle(
                color: Colors.white,
                fontSize: 14,
              ),
            )
          ],
        ),
      ),
    );
  }
}
